Overview
========

``ftw.billboard`` is a plone addon for providing a market place where users
can add ads.

The ads are addable within billboard categories and can contain images and
attachments.


Install
=======

- Add ``ftw.billboard`` to your buildout configuration:

::

  [instance]
  eggs =
    ftw.pdfgenerator

- Run buildout

- Install ``ftw.billboard`` in portal_setup.



Links
=====

- Package repository: https://github.com/4teamwork/ftw.billboard
- Issue tracker: https://github.com/4teamwork/ftw.billboard/issues
- Package on pypi: http://pypi.python.org/pypi/ftw.billboard
- Continuous integration: https://jenkins.4teamwork.ch/search?q=ftw.billboard


Copyright
=========

This package is copyright by `4teamwork <http://www.4teamwork.ch/>`_.

``ftw.billboard`` is licensed under GNU General Public License, version 2.
